@@ -418,14 +418,12 @@ pyg_source_prepare(GSource *source, gint *timeout)
     }
 
     ret = PyObject_IsTrue(PyTuple_GET_ITEM(t, 0));
-
-    if (ret) {
 	*timeout = PyInt_AsLong(PyTuple_GET_ITEM(t, 1));
+
 	if (*timeout == -1 && PyErr_Occurred()) {
 	    ret = FALSE;
 	    goto bail;
 	}
-    }
 
     got_err = FALSE;
 
@@ -653,8 +651,7 @@ PyTypeObject PyGIdle_Type = {
     (getattrofunc)0,			/* tp_getattro */
     (setattrofunc)0,			/* tp_setattro */
     0,					/* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE |
-      Py_TPFLAGS_HAVE_GC,		/* tp_flags */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,		/* tp_flags */
     NULL,				/* tp_doc */
     (traverseproc)0,			/* tp_traverse */
     (inquiry)0,				/* tp_clear */
@@ -730,8 +727,7 @@ PyTypeObject PyGTimeout_Type = {
     (getattrofunc)0,			/* tp_getattro */
     (setattrofunc)0,			/* tp_setattro */
     0,					/* tp_as_buffer */
-    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE |
-      Py_TPFLAGS_HAVE_GC,		/* tp_flags */
+    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_BASETYPE,		/* tp_flags */
     NULL,				/* tp_doc */
     (traverseproc)0,			/* tp_traverse */
     (inquiry)0,				/* tp_clear */
